<?php
/**
 * NetSuite Configuration
 * 
 * This file is auto-generated by the NetSuite settings form.
 * You can also manually edit this file if needed.
 * 
 * To configure these settings via the web interface, visit:
 * /netsuite-settings/index
 */

return [
    'enabled' => false,
    'account_id' => '',
    'consumer_key' => '',
    'consumer_secret' => '',
    'token_id' => '',
    'token_secret' => '',
    'environment' => 'production', // 'sandbox' or 'production'
];
